==> haskell-pcre-heavy-1.0.0.2-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-LOcRFdecSZN6odDALBhMpl
key: pcre-heavy-1.0.0.2-LOcRFdecSZN6odDALBhMpl
license: LicenseRef-PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
author: Greg V
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
abi: 4bcadfcbe04d13709b278ccb1bd7884d
exposed: True
exposed-modules:
    Text.Regex.PCRE.Heavy
import-dirs: /usr/lib/ghc-8.6.5/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-LOcRFdecSZN6odDALBhMpl
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 pcre-light-0.4.0.4-8zfbmBbUiMjItZRXBeQFXh
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.2-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-8aTqo4rVSPv5RK1tKtcDRl
key: pcre-heavy-1.0.0.2-8aTqo4rVSPv5RK1tKtcDRl
license: LicenseRef-PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
author: Greg V
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
abi: e64e2afbb99adfe3f6e589b23a0ecd59
exposed: True
exposed-modules:
    Text.Regex.PCRE.Heavy
import-dirs: /usr/lib/ghc-8.6.5/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-8aTqo4rVSPv5RK1tKtcDRl
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 pcre-light-0.4.0.4-8zfbmBbUiMjItZRXBeQFXh
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
